use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/XML/GrammarBase.pm',
    'lib/XML/GrammarBase/Role/DataDir.pm',
    'lib/XML/GrammarBase/Role/RelaxNG.pm',
    'lib/XML/GrammarBase/Role/XSLT.pm',
    'lib/XML/GrammarBase/Role/XSLT/Global.pm',
    't/00-compile.t',
    't/data/fiction-xml-invalid-test.xml',
    't/data/fiction-xml-test-docbook-xslt-output.docbook.xml',
    't/data/fiction-xml-test-html-xslt-output.xhtml',
    't/data/fiction-xml-test.xml',
    't/data/fiction-xml-to-docbook.xslt',
    't/data/fiction-xml-to-html.xslt',
    't/data/fiction-xml.rng',
    't/data/screenplay-xml/xml/with-tags-inside-paragraphs.xml',
    't/data_dir.t',
    't/multi-xslt.t',
    't/rng.t',
    't/xslt.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
